bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart.delete
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaToGaussianWishart.delete